import SharedElementSceneData, { SharedElementSceneEventType } from './SharedElementSceneData';
import { SharedElementEventSubscription, SharedElementTransitionProps, Route } from './types';
export declare type SharedElementRendererUpdateHandler = () => any;
export interface ISharedElementRendererData {
    startTransition(closing: boolean, navigatorId: string): void;
    endTransition(closing: boolean, navigatorId: string): void;
    updateSceneState(sceneData: SharedElementSceneData, route: Route, sceneEvent: SharedElementSceneEventType): void;
    readonly nestingDepth: number;
}
/**
 * TODO
 *
 * - [X] Start animation on `startTransition`
 * - [X] Use animValue from started navigator
 * - [X] Use route from deepest nested scene
 * - [X] Support nesting
 * - [ ] State gets messed up when transition hasnt ended yet (stops working)
 * - [ ] Not all lifecycle events not emitted by stack when using gestures (close modal)
 */
export default class SharedElementRendererData implements ISharedElementRendererData {
    private scenes;
    private updateSubscribers;
    private sharedElements;
    private isShowing;
    private animValue;
    private route;
    private prevRoute;
    private scene;
    private prevScene;
    private isTransitionStarted;
    private isTransitionClosing;
    private transitionNavigatorId;
    startTransition(closing: boolean, navigatorId: string): void;
    endTransition(closing: boolean, navigatorId: string): void;
    updateSceneState(sceneData: SharedElementSceneData, route: Route, sceneEvent: SharedElementSceneEventType): void;
    willFocusScene(sceneData: SharedElementSceneData, route: Route): void;
    didFocusScene(sceneData: SharedElementSceneData, route: Route): void;
    willBlurScene(sceneData: SharedElementSceneData, route: Route): void;
    private registerScene;
    private updateSceneListeners;
    private getScene;
    private updateSharedElements;
    addUpdateListener(handler: SharedElementRendererUpdateHandler): SharedElementEventSubscription;
    private emitUpdateEvent;
    getTransitions(): SharedElementTransitionProps[];
    get nestingDepth(): number;
}
